#
# spec file for package ranger
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define short_version 1.9.3

Name:           ranger
Version:        1.9.3+git20240221.38bb890
Release:        1.5
Summary:        Console File Manager
License:        GPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/ranger/ranger
Source:         %{name}-%{version}.tar.gz
Source99:       ranger-rpmlintrc
# PATCH-FIX-UPSTREAM ranger.desktop.patch -- Add missing GenericName
Patch0:         ranger.desktop.diff
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
Requires:       file
Requires:       python3-curses
Recommends:     atool
Recommends:     highlight
Recommends:     mediainfo
Recommends:     python3-Pillow
Recommends:     w3m
BuildArch:      noarch

%description
Ranger is a console file manager that gives you greater flexibility and a
good overview of your files without having to leave your text console. It
visualizes the directory tree in two dimensions: the directory hierarchy on
one, lists of files on the other, with a preview to the right.

The default keys are similar to those of Vim, Emacs and Midnight Commander,
though ranger is easily controllable with just the arrow keys or the mouse.

%prep
%autosetup -p1
sed -e 's|#!/usr/bin/env python|#!%{_bindir}/python3|' -i doc/tools/*.py
sed -e 's|#!/usr/bin/env bash|#!/bin/bash|' -i ranger/data/scope.sh

%build
python3 ./setup.py build

%install
python3 ./setup.py install \
  --prefix="%{_prefix}" \
  --root=%{buildroot}

mv "%{buildroot}%{_datadir}/doc/ranger" _doc
find _doc -type f -exec chmod -x '{}' +

%if 0%{?suse_version} < 1500
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
%license LICENSE
%doc _doc/*
%{_bindir}/ranger
%{_bindir}/rifle
%{python3_sitelib}/ranger_fm-%{short_version}-*.egg-info
%{python3_sitelib}/ranger
%{_mandir}/man1/ranger.1%{ext_man}
%{_mandir}/man1/rifle.1%{ext_man}
%{_datadir}/applications/%{name}.desktop

%changelog
* Sun Mar 17 2024 scott.bradnick@suse.com
- Update to version 1.9.3+git20240221.38bb890:
  * Don't crash on incomplete filter_stack input
  * mime.types: Add common requests
  * report file byte size in IIP
  * GHActions: Set TERM for test_py job
  * GHActions: Set TERM to avoid setupterm errors
  * GHActions: Fix step ID in indexing operations
  * GHActions: Rename PR workflow job to reduce confusion
  * GHActions: Run complete PR workflow if changed
  * GHActions: Drop ${{ }} from if conditionals
  * GHActions: Run all Python tests on PRs too
  * GHActions: Merge all Python tests and lints into one Action
  * shutil_generatorized: Add space to inline comment for PEP8
  * fixup! ext/shutil_generatorized: copy_file_range only on recent Linux
  * fixup! Shutil modified to use os.copy_file_range When passed the option to do so
  * Revert "CopyLoader has been modified"
  * Revert "Default setting value for new copy on write setting"
  * Revert "Syntax adjustments to pass test suite"
  * Revert "Add new copy on write setting to ALLOWED_SETTINGS"
  * Revert "Updated man files for new setting which can be used to enable copy"
  * ext/shutil_generatorized: copy_file_range only on recent Linux
  * Sorted make test errors
  * fix syntax errors
  * Revert "Fixed syntax error in shutil_generatorized.py"
  * Fixed syntax error in shutil_generatorized.py
  * Revert "Update shutil_generatorized.py"
  * Update shutil_generatorized.py
  * Update shutil_generatorized.py
  * Update shutil_generatorized.py
  * Update shutil_generatorized.py
  * Fixing syntax error in new os.copy_file_range code
  * Syntax adjustments to pass test suite
  * Shutil modified to use os.copy_file_range When passed the option to do so
  * CopyLoader has been modified To pass the new copy on write setting to shutil
  * Add new copy on write setting to ALLOWED_SETTINGS Enables setting to be used in code
  * Default setting value for new copy on write setting Ensure setting is off by default
  * Updated man files for new setting which can be used to enable copy on write functionality.
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Tue Jul 25 2023 scott.bradnick@suse.com
- Update to version 1.9.3+git20230531.1a00715:
  * Remove duplicated function next_available_filename
  * scope.sh: Enable DjVu previews by default
* Wed Apr 26 2023 scott.bradnick@suse.com
- Update to version 1.9.3+git20230425.fe7c3b2:
  * man: Document filter_dead_tabs_on_startup
  * main: Refactor to avoid TOCTOU
  * Initial version of dead-path tab switch control
  * Revert "This is a combination of 6 commits"
  * Keep duplicate tabs on startup
  * Delete dead tabs on startup conditionally
  * This is a combination of 6 commits
  * Maintain tab order while filtering out duplicates and dead entries
  * Remove non-existent paths from fm.start_paths
  * Remove duplicate tabs on startup
* Wed Apr 26 2023 Jan Engelhardt <jengelh@inai.de>
- Use multi-file find -exec
* Wed Apr 19 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- doc: clean up doc files
* Sun Apr 16 2023 scott.bradnick@suse.com
- Update to version 1.9.3+git20230416.478d5b6:
  * img_display, popen23: Appease lints
  * Move path to suffix=, add prefix="ranger"
  * GHActions: Update checkout and setup-python version
  * GHActions: Change CI to run conditionally without remaining pending
  * Fix the logic for determining the preview scale
  * Clean up the SIXEL documentation
  * Fix standard library misuse
  * Tidy up Magick executable detection logic
  * Move the ABC compat wrapper to a separate file
  * Tweaked human_readable
  * directory: Fix max call in mtimelevel
  * Added a default argument to the human_readable function
  * Reduce unnecessary string concatination
  * Reformat script
  * scope: Reformat sqlite preview for width
  * scope: Add missing parens in SQL OFFSET calculation
  * Show ellipsis `...` when reaching row limits
  * Reduce unnecessary variable assignment
  * Show row limits
  * Pretty format SQL query
  * get_executables: Use platform instead of reading /proc
  * Encourage ImageMagick to use OpenCL for processing
  * Implement the SIXEL image previewer
  * Support Expansion Of Environment Variables in cd command
  * shutil_generatorized: Float exists condition outwards
  * Disable the pylint checks for this workaround
  * Fix the ABC checks on Python 3
  * Set COLOR_PAIRS only in the cases it's relevant
  * color: Catch Color number is greater than COLORS-1
  * Skip WSL-related dirs from PATH in WSL
  * Revert "Disable multiplexer title renaming in Microsoft WSL"
  * gui.color: Change dummy key
  * doc: added binary_size_prefix option
  * doc: Add BAT_STYLE
  * Feat: Make BAT_STYLE configurable
  * Changed the default unit prefixes for file sizes
  * Change the import as per the pylint suggestion
  * Don't reinvent the regex.pattern value
  * Add the live previews for the filter stack name filters
  * Replace the legacy filter with a compatibility layer
  * Fix Python 2 support related to Subprocess
  * img_display: Drop FileExistsError for COMPAT
  * img_display: Adhere to snake_case naming
  * img_display: Directory existing is not an error
  * img_display: Fix identifier for the error message
  * img_display: Restore cleanup of Kitty tempfiles
  * img_display: Make formatting consistent
  * actions: Implement custom notify exception
  * actions: Replace SystemExit with RuntimeError
  * Pylint: Replace f-strings in port checker for Py 2 compat
  * actions: Replace raising Exception with SystemExit
  * Pylint: Use dict literals instead of dict() calls
  * directory: Drop unnecessary nested max()
  * Pylint: Disable superfluous-parens
  * scope: Resolve unreachable exit
  * Pylint: Drop explicit IAstroidChecker implements
  * Pylint: Add Python 2/3 port checker
  * Pylint: Drop redefined-variable-type disable
  * Pylint: Drop disabling locally-enabled
  * bookmarks: Drop no-self-use disable
  * requirements.txt: Drop Pylint pin.
  * img_display: Borrow implementation from imghdr
  * browsercolumn: Avoid creating intermediate list for sum
  * Pylint: Tackle unnecessary-dunder-calls
  * Pylint: Add MockFM to ignored-classes
  * GHActions: Only PyLint on latest and bump 3.5 to 3.7
  * Make display of directory size in linemodes less misleading
  * Update actions.py
  * Disable multiplexer title renaming in Microsoft WSL
  * Gracefully fallback when file(1) is not available
  * img_display: Simplify RGB(A) conversion
  * doc: w3m preview compatible with Alacritty and tmux
  * Fix case where info["transparent"] could be equal to a falsey value and still trigger warning
  * Fix image display for palette images with transparency
  * Make pylint shush about indentation and simplify-boolean-expression
  * Fix "Loader work process failed" error when copying dangling symlinks
  * Feat: add preview handler for SQLite to scope.sh
  * ueberzug suppress stderr
* Tue Feb 28 2023 scott.bradnick@suse.com
- Update to version 1.9.3+git20230222.e81adca:
  * Fix nsxiv workaround
  * fm: Add nsxiv to sxiv workaround
  * Recommend use of pipx over pip installation
* Tue Jan  3 2023 scott.bradnick@suse.com
- Update to version 1.9.3+git20221124.f8b304f:
  * rifle: Format cmd in error for copying
  * rifle_sxiv: Update comments
  * ui: Guard terminal capabalities
  * changelog, commands: Fix typos
  * Use `printf` instead of `echo`.
  * Check for --apparent-size before invoking on cwd.
  * remove outdated information on security-relevant bugs
  * remove trailing and fix indent
  * Fix NAME not displaying in man pages
  * rifle_sxiv: properly fallback on non-valid extensions
  * rifle_sxiv: add some more image extensions
  * Acknowledge and report the exit status of the rifle'd commands
* Thu Oct 13 2022 scott.bradnick@suse.com
- Renaming ranger.desktop.patch to ranger.desktop.diff
- Update to version 1.9.3+git20221008.7171fe4:
  * doc: Regenerate ranger man page
  * Update ranger.pod
* Fri Aug 19 2022 scott.bradnick@suse.com
- Update to version 1.9.3+git20220801.fcf44f6f:
  * manpage_completion_test: Change interpreter directive
  * make requested changes
  * rifle.conf: add xviewer for image mime type
* Fri Jun 17 2022 Scott Bradnick <scott.bradnick@suse.com>
- Adding 'Recommends: python3-Pillow'
* Fri Jun 17 2022 scott.bradnick@suse.com
- Update to version 1.9.3+git20220615.7e2d1613:
  * browsercolumn: Only add the separator when needed
  * GHActions: Refrain from installing PyLint for tests
  * browsercolumn: Fix separator depth
  * GHActions: Rerun PyLint when requirements.txt changes
  * pylint: Pin to 2.13.9
  * browsercolumn: Use number of items for width
  * browsercolumn: Take into account one_indexed setting
  * browsercolumn: Lowercase line_numbers in key
  * browsercolumn: Refactor linum_text_len
  * browsercolumn: Fix relative line number width
  * browsercolumn: Include linum_text_len in key
  * browsercolumn: Remove off-by-one trailing space
  * browsercolumn: Accept line_numbers case insensitively
  * browsercolumn: Fix off-by-one in line number width
  * Add viewnior in rifle config
* Fri May 27 2022 scott.bradnick@suse.com
- Update to version 1.9.3+git20220526.aaf03225:
  * test_py2_compat: Ignore error message positions
  * runner: Initialize variables outside of try-except
  * accumulator: Make get_list an abstract method
  * colorscheme: Make use an abstract method
* Fri Apr 22 2022 scott.bradnick@suse.com
- Update to version 1.9.3+git20220401.391f061c:
  * doc: Add draw.io dependency to man page
  * README: Add draw.io dependency
  * scope: Fix draw.io width and enable by default
  * scope: Move draw.io preview to handle_image
  * Makefile: Drop README.md from man page requisites
  * doc: Split lines in man page
  * doc: Add openscad dependency to man page
  * doc: Fix manpage for name filter_stack filter
  * fix indent
  * better textual preview for jupyter notebooks
* Tue Dec 31 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.9.3
  * Added Comic cbz/cbr previews
  * Added DjVu previews
  * Added Font previews
  * Added Wayland support to rifle
  * Added `imv` to rifle
  * Added `paste_ext` command with new name collision behavior
  * Added a `size_in_bytes` setting
  * Added a new `%%any_path` macro to simplify use of bookmarks
    in commands
  * Added a new image previewing method using `ueberzug`
  * Added archive previews
  * Added filters for uniqueness and duplicates by hash to
    `filter_stack`
  * Added generic openers to rifle, `xdg-open` for example
  * Added line modes with human readable size information
  * Added loading of plugins from local configuration directory
  * Added previews for 3d models using `openscad`
  * Added previews of MS Office documents
  * Added scrolling in preview
  * Added trash functionality to ranger, as alternative to
    deleting files
  * Added zathura to rifle
  * Changed `c/p/tunmap` to `unc/p/tmap` respectively, fixing
    them in the process
  * Changed argument order for `tag_toggle`
  * Fixed `chmod` behavior with `000` quantifier
  * Fixed a crash involving `Ctrl+space`
  * Fixed behavior of statusbar when resizing terminal window
  * Fixed busyloop when ranger's STDIN was closed
  * Fixed drawing of borders in st
  * Fixed handling of macros for `chain`
  * Fixed unicode decoding errors for previews
  * Improved VCS integration by truncating long commit messages
  * Improved `bulkrename` behavior when moving files to a
    non-existing directory
  * Improved `bulkrename`'s handling of files with utf-16
    surrogates in the name
  * Improved behavior of `rename_append` for directories
  * Improved configurability of syntax highlighting previews
  * Improved coverage of unofficial MIME types, mostly audio
    formats
  * Improved documentation of `multipane` viewmode
  * Improved documentation of optional dependencies
  * Improved documentation on `copymap`
  * Improved documentation on `tab_shift`
  * Improved documentation on `w3m_offset`
  * Improved example shell scripts
  * Improved extensibility of image previewing methods using a
    registry
  * Improved fuzzy tab completion
  * Improved guessing of file encoding
  * Improved handling of configuration and cache directories
    when using `--clean`
  * Improved handling of invalid mtimes (Relevant for fuse
    mounts)
  * Improved logging of file deletion
  * Improved testing and CI setup
  * Improved updating of tmux/screen window names
  * Improved updating of window titles
  * Improved validation of bookmarks
  * Improved w3m preview method for terminals that aren't quite
    compatible
- Refreshed ranger.desktop.patch
* Mon Sep 10 2018 aloisio@gmx.com
- Update to version 1.9.2
  * Added a `hint_collapse_threshold` setting
  * Added a `traverse_backwards` command analogous to `traverse`
  * Added a command to shift tabs
  * Added a normal mode mapping to quickly enter the console and
    scroll through the history `C-p`
  * Added a section to `scope.sh` for image previews of archives
  * Added an avfs plugin
  * Added an option to the move command to enable launching the
    selected file instead of the marked files
  * Added filtering functionality inspired by dired's filter
    stack, `.n, .| ...`
  * Added image preview method for Kitty
  * Added option to disable the display of free space for high
    latency situations
  * Added section to `scope.sh` for pdf previews with mutool
  * Added several emacs/readline-inspired keybindings, `C-g` for
    `ESC`, `alt-f/b`
  * Added systemwide `rc.conf` and `commands.py` in `/etc/ranger`
  * Added the `%%any_path` macro to allow bookmarks to be used
    with commands that need a path and are unaware of bookmarks
  * Added versioning logic to include extra info in unreleased
    versions
  * Change tab saving to save all tabs, not just the active tab
  * Changed `draw_borders` setting to enable drawing only
    borders or seperators
  * Changed behavior of positional arguments to the ranger
    command, if you specify a path to a file ranger will open
    with that file selected
  * Changed the `tilde_in_titlebar` setting to influence the
    window titlebar too
  * Changed the default colorscheme to work properly in
    terminals that don't equate bold and bright
  * Fixed StopIteration errors
  * Fixed embedded null errors
  * Fixed issues reported by coverity scan
  * Fixed running ranger as root on Mac OS
  * Fixed unicode issue for python2
  * Fixed w3m preview issues with black stripes
  * Improved PEP8 adherence
  * Improved VCS symbols
  * Improved `--cmd` functionality
  * Improved file encoding detection by using chardet if it's
    available
  * Rifle's flag t should now work with more terminals than
    xterm and urxvt
  * Update colorscheme documentation
- Fixed license field
* Thu Feb 22 2018 aloisio@gmx.com
- Update to version 1.9.1
  * Fixed the rifle config backwards compatibility (regression in
    1.9.0)
  * Fixed the POSIX compatibility of `Makefile`
  * Fixed `--choosefile`, `--choosefiles` and `--choosedir` so
    they work with the process substitution (`>(...)` in Bash)
  * Changed the default `gt` binding to `gp` due to a conflict
  * Changed the help message for `--choosefile`, `--choosefiles`
    and `--choosedir` to avoid confusion
  * Changed the behavior of `:reset` to reload the tags too
  * Added `geeqie` to the default `rifle.conf`
* Sun Jan 28 2018 aloisio@gmx.com
- Update to version 1.9.0
  * Fixed memory leak in w3m image preview
  * Fixed `Q` binding, map it to `quitall` instead of `quit!`
  * Fixed `gR` binding
  * Fixed custom linemode not being applied to files
  * Fixed w3m image display invocation on OpenBSD
  * Fixed broken pager after changing view mode with `~`
  * Added reset of rifle.conf when pressing `<C-R>`
  * Added image-based PDF previews to `scope.sh` (disabled by
    default)
  * Added terminology-based image previews
  * Added check for `$VISUAL` environment variable
  * Added setting `iterm2_font_height` and `iterm2_font_width`
  * Renamed setting `cd_tab_smart` to `cd_tab_fuzzy`
  * Changed command for mercurial integration from `hg` to `chg`
  version 1.9.0b6
  * Fixed crash when parsing corrupted history file
  * Fixed tab completion with `cd -r ...`
  * Fixed crash when previewing files encoded in little-endian
    UTF-16
  * Fixed flicker in previewing symlinked images
  * Fixed detection of location of scope.sh
  * Fixed crash when running ranger from the directory containing
    its package
  * Fixed cursor position after moving half a page down and back up
  * Fixed handling of lines that are too long for the console
  * Added `<F2>` binding to `:rename_append`
  * Avoid dereferencing symlinked directory when starting ranger
    in one
  * Added support for `file://` URIs as path arguments
  * Added setting `save_tabs_on_exit`
  * Added setting `cd_tab_case`, sets case sensitivity of `:cd`
    tab completion
  * Added setting `cd_tab_smart`, allows fuzzy tab completion with
    `:cd`, for example, `:cd /u/lo/b<TAB>` expands to
    `:cd /usr/local/bin`
  * Added setting `global_inode_type_filter` to show only
    directories when running ranger with the new option
    `--show-only-dirs`
  * Added setting `save_backtick_bookmark`, e.g. for easier
    syncing of bookmarks
  * Added setting `one_indexed` to start counting line numbers
    from 1
  * Added rifle.conf entries to list/extract archives without atool
  * Added `:yank` command for simplified definitions of `yn`, `yd`
    & `yp`
  * Added `:narrow` command, which filters selected files
  * Added setting `freeze_files`, bound to `F` key, to avoid
    reloading files
  * Changed `:shell -p ...` to display stderr in pager
  version 1.9.0b5
  * Fixed width calculation of multibyte characters in preview
  * Fixed crash in iTerm2 preview with python 3.5
  version 1.9.0b1
  * Fixed crash when using `Mi` on files without reading
    permissions
  * Fixed natural sorting (`11.jpg` < `100.jpg`)
  * Fixed loss of precision in timestamps when copying
  * Fixed smart case matching in `:travel`
  * Fixed automatically disabling `preview_script` when running as
    root
  * Fixed crash on sshfs disconnect
  * Fixed crash on missing `~/.config/ranger/history`
  * Fixed crash when path not accessible during start-up
  * Fixed automatic tmux title
  * Fixed urxvt image previewing when running tmux
  * Fixed macro expansion in aliased commands
  * Fixed `hidden_filter` option when combined with `:flat`
  * Fixed various other crashes
  * Fixed error message that occasionally pops up when changing
    settings
  * Introduced extensive linting to ensure code quality
  * Added continuous integration.  Patches now require `make test`
    to pass.
  * Added handling of arguments in "$PAGER" environment variable
  * Added quote parsing for `:setlocal path=...`
  * Added `ys` to copy the selection to clipboard
  * Added setting `hostname_in_titlebar`
  * Added setting `wrap_scroll` to wrap cursor around when
    scrolling
  * Added example plugin `plugin_fasd_add.py`
  * Added command `jump_non` to jump to the first non-directory
    file
  * Added additional arguments to the command `:rename_append`
  * Added key binding 'zz' as an alternative to 'zf'
  * Added option `-c` to the `rifle` file opener command
  * Added support for `$XDG_DATA_HOME`
  * Avoid exiting ranger while copying.  Use `:quit!` to quit
    while copying.
  * Improved scope.sh (better performance & readability)
  * Changed `ranger --choosefiles` to return all selected files in
    all paths
  * Changed interpretation of commands: treat tabs as argument
    separators
  * Changed `<C-n>` to open new tab in current directory rather
    than `$HOME`
  * Changed `:quit!` to only close 1 tab.  Use `:quitall` to close
    all tabs.
  * Removed backward compatibility for `options.py`, predecessor
    of `rc.conf`
  * Automatically update bookmarks+tags when renaming them via
    ranger
- New URL and source address.
- Switched to python3
- Spec cleanup
* Wed Dec 27 2017 antoine.belvire@opensuse.org
- Fix wrong conditionals for desktop_database_post(un) calls.
* Mon Dec 11 2017 sogal@volted.net
- Update desktop database upon ranger installation/removal
- Fixed desktop file by adding GenericName entry using
  ranger.desktop.patch
* Sat Jan 21 2017 aloisio@gmx.com
- Update to version 1.8.1
  * Fixed `:scout` break due to incompatible change
    in python 3.6
* Wed Dec 28 2016 jengelh@inai.de
- Trim filler words from description
* Sat Dec 24 2016 aloisio@gmx.com
- Update to version 1.8.0
  * scope.sh is now needed for the now fully scriptable image
    previews
  * Overhaul of version control system integration, now with
    threads
  * Fixed ranger not finding the location of w3mimgdisplay in
    most cases
  * Fixed many minor bugs
  * Added midnight-commander like multipane view, toggleable
    with `~` key. It displays the current directory of all the
    open tabs next to each other.
  * Added autodetect for 256 color support in scope.sh source
    code preview
  * Added macro `%%confdir` that expands to `~/.config/ranger`
    by default
  * Added possibility to toggle/cycle through options with
    `set <option_name>!`
  * Added `Mm`/`Ms` key to enable the linemode showing
    modification time
  * Added `yt`/`dt` keys to toggle whether file is in copy/cut
    buffer
  * Added `line_numbers` setting showing absolute/relative
    line numbers
  * Added `Alt-Left` and `Alt-Right` key bindings to move by
    words in console
  * Added previews for libreoffice files with `odt2txt`
  * Added `preview_images_method=urxvt` option for previewing
    images by changing the urxvt background (requires urxvt
    compiled with pixbuf support)
  * Added `clear_filters_on_dir_change` option
  * Added Travis-CI integration
  * Changed `zi` key to toggle `preview_images` option
  * Improved PEP8 compliance
  * Improved documentation
  * Improved UI by separating file path in title bar with a
    space from the  username/hostname for quick copy&pasting by
    shift+double-clicking on it.
- Dropped ranger.desktop now supplied from upstream
* Sat Nov  5 2016 aloisio@gmx.com
- Update to version 1.7.2
  * Fixed file name arguments passed to "sxiv" and "feh" when
    using ":flat"
  * Fixed removal of empty directories when using ":rename"
  * Fixed free disk space display on Mac OS X
  * Fixed `examples/vim_file_chooser` to work with gvim too
  * Fixed some other rare crashes and bugs
  * Fixed downward mouse wheel scrolling
  * Fixed warning about regex splits being drawin in title bar
    since python3.5
  * Really fixed "S" key binding not working when SHELL=fish
  * Improved doc/cheatsheet.svg
  * Added some entries to rifle.conf
  * Added key bindings pO and pP which work like po and pp but
    queue the operation in a first-in-first-out order.
  version 1.7.1
  * Added doc/cheatsheet.svg
  * Added examples/rc_emacs.conf, a config file adding
    emacs-like key bindings
  * Added "env" keyword in rifle.conf
  * Fixed ":bulkrename" command in python3
  * Fixed "S" key binding not working when SHELL=fish
  version 1.7.0
  * The default editor is now "vim" instead of "nano"
  * Added automatic updates of tags when a file is renamed
    from within ranger
  * Added "preview_images_method" which can be set to "iterm2"
    to use native iTerm2 image previews
  * Added ":rename_append" command to rename files without the
    file extension
  * Added ":linemode" command to change the way the files are
    displayed. Try this out by pressing M followed by one of
    the  suggested keys. New linemodes can be added with
    ranger.api.register_linemode().
  * Added ":filter_inode_type" command to only show
    directories, files or links
  * Added ":meta" command for managing custom file metadata
  * Added ":flat" command for displaying subdirectories
  * Added "solarized" colorscheme
  * Added generic ability to use scope.sh for image previews
  * Added video previews in scope.sh
  * Added option "sort_unicode" to sort according to unicode,
    not ASCII
  * ":mkdir" can now create multiple directory levels (like
    `mkdir -p`)
  * ":help" (key binding "?") is now interactive
  * ":find" (key binding "/") is now case insensitive by
    default
  * "ranger --copy-config=all" now copies a short sample
    commands.py rather than the full one, so that you can
    update ranger without having broken commands. The full
    commands.py is still copied to
    ~/.config/ranger/commands_full.py.
  * Fixed broken copying of symlinks
- Spec cleanup
* Mon Jul 15 2013 pascal.bleser@opensuse.org
- update to 1.6.1
- add required dependency on python-curses
* Thu May 26 2011 pascal.bleser@opensuse.org
- initial version (1.4.3)
